package com.patzn.cloud.service.lims.soil.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.mapper.Condition;
import com.baomidou.mybatisplus.plugins.Page;
import com.patzn.cloud.commons.api.RestConstants;
import com.patzn.cloud.commons.api.RestResult;
import com.patzn.cloud.commons.controller.ServiceController;
import com.patzn.cloud.service.soil.entity.SoilSampleRecord;
import com.patzn.cloud.service.lims.soil.service.ISoilSampleRecordService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * <p>
 * 土工试验样品操作日志表 前端控制器
 * </p>
 *
 * @author wwd
 * @since 2020-09-11
 */
@Api(description = "土工试验样品操作日志表")
@RestController
@RequestMapping("/v1/sample_record")
public class SoilSampleRecordController extends ServiceController  {

    @Autowired
    private ISoilSampleRecordService soilSampleRecordService;


    @ApiOperation(value = "分页列表", notes = "分页查询数据列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataType = "String"),
    })
    @PostMapping("/page")
	public RestResult<Page<SoilSampleRecord>> getPage(SoilSampleRecord soilSampleRecord) {
        return success(soilSampleRecordService.page(getPage(), soilSampleRecord));
	}


    @ApiOperation(value = "查询列表", notes = "查询数据列表")
    @PostMapping("/list")
    public RestResult<List<SoilSampleRecord>> getList(SoilSampleRecord soilSampleRecord) {
        return success(soilSampleRecordService.list(soilSampleRecord));
    }


    @ApiOperation(value = "查询 id 信息", notes = "查询指定 id 的数据内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键", required = true, paramType = "path", dataType = "long"),
    })
    @GetMapping("/{id}")
    public RestResult<SoilSampleRecord> get(@PathVariable("id") Long id) {
        return success(soilSampleRecordService.getById(id));
    }


    @ApiOperation(value = "根据 id 修改信息", notes = "根据指定 id 修改该条数据内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键", required = true, paramType = "path", dataType = "long"),
    })
    @PutMapping("/{id}")
	public RestResult<Boolean> edit(@PathVariable("id") Long id, SoilSampleRecord soilSampleRecord) {
        soilSampleRecord.setId(id);
        return success(soilSampleRecordService.updateById(soilSampleRecord));
	}


    @ApiOperation(value = "添加", notes = "添加一条数据")
    @PostMapping("/")
	public RestResult<Boolean> add(SoilSampleRecord soilSampleRecord) {
        return success(soilSampleRecordService.save(soilSampleRecord));
	}


    @ApiOperation(value = "根据 ids 删除", notes = "根据 id 数组删除指定的数据内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids", value = "主键数组", required = true, paramType = "query", dataType = "array"),
    })
	@DeleteMapping("/")
	public RestResult<Boolean> delete(@RequestParam("ids") Long[] ids) {
        return success(soilSampleRecordService.remove(Condition.create().in("id", ids)));
	}

}
